diff --git a/binaries/data/mods/public/audio/interface/complete/building/complete_blacksmith.ogg b/binaries/data/mods/public/audio/interface/complete/building/complete_forge.ogg
similarity index 100%
rename from binaries/data/mods/public/audio/interface/complete/building/complete_blacksmith.ogg
rename to binaries/data/mods/public/audio/interface/complete/building/complete_forge.ogg
diff --git a/binaries/data/mods/public/audio/interface/complete/building/complete_blacksmith.xml b/binaries/data/mods/public/audio/interface/complete/building/complete_forge.xml
similarity index 90%
rename from binaries/data/mods/public/audio/interface/complete/building/complete_blacksmith.xml
rename to binaries/data/mods/public/audio/interface/complete/building/complete_forge.xml
index ed44a78d34..d390bac873 100644
--- a/binaries/data/mods/public/audio/interface/complete/building/complete_blacksmith.xml
+++ b/binaries/data/mods/public/audio/interface/complete/building/complete_forge.xml
@@ -11,5 +11,5 @@
1
1
audio/interface/complete/building
- complete_blacksmith.ogg
+ complete_forge.ogg
diff --git a/binaries/data/mods/public/audio/interface/select/building/sel_blacksmith.ogg b/binaries/data/mods/public/audio/interface/select/building/sel_forge.ogg
similarity index 100%
rename from binaries/data/mods/public/audio/interface/select/building/sel_blacksmith.ogg
rename to binaries/data/mods/public/audio/interface/select/building/sel_forge.ogg
diff --git a/binaries/data/mods/public/audio/interface/select/building/sel_blacksmith.xml b/binaries/data/mods/public/audio/interface/select/building/sel_forge.xml
similarity index 90%
rename from binaries/data/mods/public/audio/interface/select/building/sel_blacksmith.xml
rename to binaries/data/mods/public/audio/interface/select/building/sel_forge.xml
index 2d6a33ef74..68917c2afa 100644
--- a/binaries/data/mods/public/audio/interface/select/building/sel_blacksmith.xml
+++ b/binaries/data/mods/public/audio/interface/select/building/sel_forge.xml
@@ -10,5 +10,5 @@
1
1
audio/interface/select/building
- sel_blacksmith.ogg
+ sel_forge.ogg
diff --git a/binaries/data/mods/public/gui/text/tips/blacksmith.txt b/binaries/data/mods/public/gui/text/tips/forge.txt
similarity index 88%
rename from binaries/data/mods/public/gui/text/tips/blacksmith.txt
rename to binaries/data/mods/public/gui/text/tips/forge.txt
index dee0ac8549..74e59e0a25 100644
--- a/binaries/data/mods/public/gui/text/tips/blacksmith.txt
+++ b/binaries/data/mods/public/gui/text/tips/forge.txt
@@ -1,3 +1,3 @@
-BLACKSMITH
+FORGE
Research structure for all factions.
Research weapon and armor upgrades for your units.
diff --git a/binaries/data/mods/public/maps/random/jebel_barkal.js b/binaries/data/mods/public/maps/random/jebel_barkal.js
index 6bf7a0ad78..7339fcc495 100644
--- a/binaries/data/mods/public/maps/random/jebel_barkal.js
+++ b/binaries/data/mods/public/maps/random/jebel_barkal.js
@@ -71,7 +71,7 @@ const oFortress = "structures/kush_fortress";
const oTower = g_MapSettings.Size >= 256 && getDifficulty() >= 3 ? "structures/kush_defense_tower" : "structures/kush_sentry_tower";
const oHouse = "structures/kush_house";
const oMarket = "structures/kush_market";
-const oBlacksmith = "structures/kush_blacksmith";
+const oForge = "structures/kush_forge";
const oBlemmyeCamp = "structures/kush_blemmye_camp";
const oNubaVillage = "structures/kush_nuba_village";
const oCivicCenter = "structures/kush_civil_centre";
@@ -181,7 +181,7 @@ const clTemple = g_Map.createTileClass();
const clRitualPlace = g_Map.createTileClass();
const clPyramid = g_Map.createTileClass();
const clHouse = g_Map.createTileClass();
-const clBlacksmith = g_Map.createTileClass();
+const clForge = g_Map.createTileClass();
const clStable = g_Map.createTileClass();
const clElephantStables = g_Map.createTileClass();
const clCivicCenter = g_Map.createTileClass();
@@ -300,10 +300,10 @@ const layoutKushCity = [
"painters": new TileClassPainter(clMarket)
},
{
- "templateName": "uncapturable|" + oBlacksmith,
+ "templateName": "uncapturable|" + oForge,
"difficulty": "Very Easy",
- "constraints": avoidClasses(clBlacksmith, 30),
- "painters": new TileClassPainter(clBlacksmith)
+ "constraints": avoidClasses(clForge, 30),
+ "painters": new TileClassPainter(clForge)
},
{
"templateName": oNubaVillage,
@@ -1061,7 +1061,7 @@ var areaCityBushes =
clTower, 1,
clFortress, 1,
clHouse, 1,
- clBlacksmith, 1,
+ clForge, 1,
clElephantStables, 1,
clStable, 1,
clCivicCenter, 1,
diff --git a/binaries/data/mods/public/maps/scenarios/cinema_demo.xml b/binaries/data/mods/public/maps/scenarios/cinema_demo.xml
index 9cbd73b495..fc21f0e57e 100644
--- a/binaries/data/mods/public/maps/scenarios/cinema_demo.xml
+++ b/binaries/data/mods/public/maps/scenarios/cinema_demo.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:778af44b4a88c05f8737c9815274d0dc48ebad2a81cf58a87c78830f6d8bad1d
-size 427305
+oid sha256:1d70a711ee083182d599a2234815d791469eed9b74caf08fc2684ed22f278866
+size 427300
diff --git a/binaries/data/mods/public/maps/scenarios/napata_reconstruction.xml b/binaries/data/mods/public/maps/scenarios/napata_reconstruction.xml
index 19741d0b0b..15acd1a1f0 100644
--- a/binaries/data/mods/public/maps/scenarios/napata_reconstruction.xml
+++ b/binaries/data/mods/public/maps/scenarios/napata_reconstruction.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:684664d2d1afb44b6e1128638cf22c854922e6696dae7c60740d625249c8831e
-size 2890655
+oid sha256:99e2358225109e83f4333be62332250d81fa58ccecc1b39401698d216ed7763a
+size 2890595
diff --git a/binaries/data/mods/public/maps/scenarios/sandbox_athenians.xml b/binaries/data/mods/public/maps/scenarios/sandbox_athenians.xml
index 0c28599b55..b04e2cf9cd 100644
--- a/binaries/data/mods/public/maps/scenarios/sandbox_athenians.xml
+++ b/binaries/data/mods/public/maps/scenarios/sandbox_athenians.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:c6419ee8ac5ff3f73722489c77a985a2dd675ba2f78c9dd462e8e79f18789164
-size 271507
+oid sha256:5ac4ff0f70f2097f7ccc029cd0d7fd475af564644b178bc325ee36c9eb0dafda
+size 271502
diff --git a/binaries/data/mods/public/maps/scenarios/sandbox_britons.xml b/binaries/data/mods/public/maps/scenarios/sandbox_britons.xml
index 1d184103c2..944ef7c0b1 100644
--- a/binaries/data/mods/public/maps/scenarios/sandbox_britons.xml
+++ b/binaries/data/mods/public/maps/scenarios/sandbox_britons.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:802f1f05ab9b02b70b970df63af9c2622d8dc12ca0a844d5e0f1e1df776824f2
-size 683306
+oid sha256:f35b324f7c614e9dad2905b213124009ade0d479e4e52735fb19ecb462486410
+size 683301
diff --git a/binaries/data/mods/public/maps/scenarios/sandbox_carthaginians.xml b/binaries/data/mods/public/maps/scenarios/sandbox_carthaginians.xml
index adbc0c6fb8..3caef86ab1 100644
--- a/binaries/data/mods/public/maps/scenarios/sandbox_carthaginians.xml
+++ b/binaries/data/mods/public/maps/scenarios/sandbox_carthaginians.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:740be2848849821eab9f113e360a57d4608fc5ae75a54854c339a87efbad1d5d
-size 175581
+oid sha256:ec31298522f6d6594bdd3283ba32ac4235033090bd4f7892861ed33f70b19737
+size 175576
diff --git a/binaries/data/mods/public/maps/scenarios/sandbox_gauls.xml b/binaries/data/mods/public/maps/scenarios/sandbox_gauls.xml
index cbc71f4d64..925c8defc2 100644
--- a/binaries/data/mods/public/maps/scenarios/sandbox_gauls.xml
+++ b/binaries/data/mods/public/maps/scenarios/sandbox_gauls.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:e8156e1bce31d239f314cfa005b73714623c8b8e12e80b8fa7c2b8cdcb4f0a1a
-size 684935
+oid sha256:81d0d2d51c5226f12fcfc74223e6f520d299f335b8de555d9420ff39e45fa859
+size 684930
diff --git a/binaries/data/mods/public/maps/scenarios/sandbox_iberians.xml b/binaries/data/mods/public/maps/scenarios/sandbox_iberians.xml
index 2e1f3f2fd5..a0036c40c3 100644
--- a/binaries/data/mods/public/maps/scenarios/sandbox_iberians.xml
+++ b/binaries/data/mods/public/maps/scenarios/sandbox_iberians.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:075f0fa9284c363017c49b291ff0d4f607601f3dfc9d27eb32974fa695bf4fa3
-size 113945
+oid sha256:f5c1f42363512503c131c624a7c609ad5978ed3469a5c5456f5287a17f1db71f
+size 113940
diff --git a/binaries/data/mods/public/maps/scenarios/sandbox_macedonians.xml b/binaries/data/mods/public/maps/scenarios/sandbox_macedonians.xml
index 0c27b97210..6c2346b65c 100644
--- a/binaries/data/mods/public/maps/scenarios/sandbox_macedonians.xml
+++ b/binaries/data/mods/public/maps/scenarios/sandbox_macedonians.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:b3bf66e55d9b4709f7f501a8bf1ae2ff95ec4d665a0251f2057779a4636905f6
-size 318108
+oid sha256:b147a44b59e1893cc874416ed1940169fa7aeb37b6587f6932062b37b1865dc5
+size 318103
diff --git a/binaries/data/mods/public/maps/scenarios/sandbox_persians.xml b/binaries/data/mods/public/maps/scenarios/sandbox_persians.xml
index d9693946fc..1c903924b4 100644
--- a/binaries/data/mods/public/maps/scenarios/sandbox_persians.xml
+++ b/binaries/data/mods/public/maps/scenarios/sandbox_persians.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:b4fc451c8fa5dc162518d2ec5a0c41a969ac3dbc883bb658a51e23f71536a9e8
-size 262725
+oid sha256:cea9cc966c431f48ed02f9d61336bdc657432058c3f27ea57137103565d68dd8
+size 262720
diff --git a/binaries/data/mods/public/maps/scenarios/sandbox_ptolemies.xml b/binaries/data/mods/public/maps/scenarios/sandbox_ptolemies.xml
index 5ed35b21dd..66c45257dc 100644
--- a/binaries/data/mods/public/maps/scenarios/sandbox_ptolemies.xml
+++ b/binaries/data/mods/public/maps/scenarios/sandbox_ptolemies.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:f4ce4a0216b88ecd1d5c76e53808e49d37d4dd5312831215e2414ce966c72337
-size 358197
+oid sha256:7b92a267d3023b7ba29d2f85863d455d1b0bf0d222951e30801c7f42773085d1
+size 358192
diff --git a/binaries/data/mods/public/maps/scenarios/sandbox_ptolemies_02.xml b/binaries/data/mods/public/maps/scenarios/sandbox_ptolemies_02.xml
index 96aca82b55..a07d69ff70 100644
--- a/binaries/data/mods/public/maps/scenarios/sandbox_ptolemies_02.xml
+++ b/binaries/data/mods/public/maps/scenarios/sandbox_ptolemies_02.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:aabfee2abd0941b17ea0efe21edcfb1f128eeffd89accd307d0f1e402422783a
-size 477973
+oid sha256:673606098efc5f093c778622ba9bb8a21c711c275ba5d63bd42846bec5251fa7
+size 477968
diff --git a/binaries/data/mods/public/maps/scenarios/sandbox_romans.xml b/binaries/data/mods/public/maps/scenarios/sandbox_romans.xml
index 7ac7bcafd5..fdcf8ebcca 100644
--- a/binaries/data/mods/public/maps/scenarios/sandbox_romans.xml
+++ b/binaries/data/mods/public/maps/scenarios/sandbox_romans.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:7ea60ab7922bf5c8b7904adade121ba71ab300d4663ed55f244b67d0c005a109
-size 359626
+oid sha256:b8602b854f064b51199f7f2750dfc832fcf59441dcdaca12df196391302bff8c
+size 359621
diff --git a/binaries/data/mods/public/maps/scenarios/sandbox_seleucids.xml b/binaries/data/mods/public/maps/scenarios/sandbox_seleucids.xml
index af9db71418..456d37c217 100644
--- a/binaries/data/mods/public/maps/scenarios/sandbox_seleucids.xml
+++ b/binaries/data/mods/public/maps/scenarios/sandbox_seleucids.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:18eb153a4e71de899fdae94f6fcd2f6e161bf43fb11a8562a96f46bfd1fa8424
-size 382397
+oid sha256:7292e0d5d53dcefe4627a6fb9439cd42065c8d433fb3b3849cbbdd64f6ebef6f
+size 382392
diff --git a/binaries/data/mods/public/maps/scenarios/sandbox_spartans.xml b/binaries/data/mods/public/maps/scenarios/sandbox_spartans.xml
index b2a383ffae..cb8e420df2 100644
--- a/binaries/data/mods/public/maps/scenarios/sandbox_spartans.xml
+++ b/binaries/data/mods/public/maps/scenarios/sandbox_spartans.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:3bb41558f4f7063c1415b132858364290b0ba067e5f1b3419278e4216fbde896
-size 250003
+oid sha256:cd14db56ad3bbc3ecfaa9fcc8898ff06183588f614626596c8ca63e262592e58
+size 249998
diff --git a/binaries/data/mods/public/maps/skirmishes/egypt_3pv3p.xml b/binaries/data/mods/public/maps/skirmishes/egypt_3pv3p.xml
index c0d85d60f4..a73c36b1a9 100644
--- a/binaries/data/mods/public/maps/skirmishes/egypt_3pv3p.xml
+++ b/binaries/data/mods/public/maps/skirmishes/egypt_3pv3p.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:7bc1da0e8c9baf974ef89c7fedc652e365860ad42739b3de457656f28ec14867
-size 3669160
+oid sha256:13d86c2f27cd02e802daba5880e25660755f31b74ffd60237dd98e63d38814fb
+size 3669125
diff --git a/binaries/data/mods/public/maps/skirmishes/skirmish_demo.xml b/binaries/data/mods/public/maps/skirmishes/skirmish_demo.xml
index 9a8b42568f..1b61770c91 100644
--- a/binaries/data/mods/public/maps/skirmishes/skirmish_demo.xml
+++ b/binaries/data/mods/public/maps/skirmishes/skirmish_demo.xml
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:c9ba6a572edd89d7633018d0ede01cbc97fefe6de3d0ea9fc8b5345b2def8820
-size 122435
+oid sha256:cbe0695c760cdf8d2ed2339a76ce21ef09463da0083232839783ecc952a3d773
+size 122430
diff --git a/binaries/data/mods/public/maps/tutorials/introductory_tutorial.js b/binaries/data/mods/public/maps/tutorials/introductory_tutorial.js
index 7babeca37a..c516bb88cf 100644
--- a/binaries/data/mods/public/maps/tutorials/introductory_tutorial.js
+++ b/binaries/data/mods/public/maps/tutorials/introductory_tutorial.js
@@ -271,10 +271,10 @@ Trigger.prototype.tutorialGoals = [
}
},
{
- "instructions": markForTranslation("Build a Blacksmith and research the Infantry Training technology (sword icon) to improve infantry hack attack."),
+ "instructions": markForTranslation("Build a Forge and research the Infantry Training technology (sword icon) to improve infantry hack attack."),
"OnResearchQueued": function(msg)
{
- if (msg.technologyTemplate && TriggerHelper.EntityMatchesClassList(msg.researcherEntity, "Blacksmith"))
+ if (msg.technologyTemplate && TriggerHelper.EntityMatchesClassList(msg.researcherEntity, "Forge"))
this.NextGoal();
}
},
diff --git a/binaries/data/mods/public/simulation/ai/petra/attackPlan.js b/binaries/data/mods/public/simulation/ai/petra/attackPlan.js
index a1141c5032..3ffbdc404f 100644
--- a/binaries/data/mods/public/simulation/ai/petra/attackPlan.js
+++ b/binaries/data/mods/public/simulation/ai/petra/attackPlan.js
@@ -1454,8 +1454,8 @@ PETRA.AttackPlan.prototype.update = function(gameState, events)
// do not loose time destroying buildings which do not help enemy's defense and can be easily captured later
if (this.target.hasDefensiveFire())
{
- targetClassesUnit.avoid = targetClassesUnit.avoid.concat("House", "Storehouse", "Farmstead", "Field", "Blacksmith");
- targetClassesSiege.avoid = targetClassesSiege.avoid.concat("House", "Storehouse", "Farmstead", "Field", "Blacksmith");
+ targetClassesUnit.avoid = targetClassesUnit.avoid.concat("House", "Storehouse", "Farmstead", "Field", "Forge");
+ targetClassesSiege.avoid = targetClassesSiege.avoid.concat("House", "Storehouse", "Farmstead", "Field", "Forge");
}
if (this.unitCollUpdateArray === undefined || !this.unitCollUpdateArray.length)
diff --git a/binaries/data/mods/public/simulation/ai/petra/config.js b/binaries/data/mods/public/simulation/ai/petra/config.js
index 6e498e036a..1667e75e67 100644
--- a/binaries/data/mods/public/simulation/ai/petra/config.js
+++ b/binaries/data/mods/public/simulation/ai/petra/config.js
@@ -18,7 +18,7 @@ PETRA.Config = function(difficulty, behavior)
"fortressLapseTime": 390, // Time to wait between building 2 fortresses
"popForBarracks1": 25,
"popForBarracks2": 95,
- "popForBlacksmith": 65,
+ "popForForge": 65,
"numSentryTowers": 1
};
@@ -260,7 +260,7 @@ PETRA.Config.prototype.setConfig = function(gameState)
this.popScaling = Math.sqrt(maxPop / 300);
this.Military.popForBarracks1 = Math.min(Math.max(Math.floor(this.Military.popForBarracks1 * this.popScaling), 12), Math.floor(maxPop/5));
this.Military.popForBarracks2 = Math.min(Math.max(Math.floor(this.Military.popForBarracks2 * this.popScaling), 45), Math.floor(maxPop*2/3));
- this.Military.popForBlacksmith = Math.min(Math.max(Math.floor(this.Military.popForBlacksmith * this.popScaling), 30), Math.floor(maxPop/2));
+ this.Military.popForForge = Math.min(Math.max(Math.floor(this.Military.popForForge * this.popScaling), 30), Math.floor(maxPop/2));
this.Economy.popPhase2 = Math.min(Math.max(Math.floor(this.Economy.popPhase2 * this.popScaling), 20), Math.floor(maxPop/2));
this.Economy.workPhase3 = Math.min(Math.max(Math.floor(this.Economy.workPhase3 * this.popScaling), 40), Math.floor(maxPop*2/3));
this.Economy.workPhase4 = Math.min(Math.max(Math.floor(this.Economy.workPhase4 * this.popScaling), 45), Math.floor(maxPop*2/3));
diff --git a/binaries/data/mods/public/simulation/components/Identity.js b/binaries/data/mods/public/simulation/components/Identity.js
index 057a7c4694..02d15672d4 100644
--- a/binaries/data/mods/public/simulation/components/Identity.js
+++ b/binaries/data/mods/public/simulation/components/Identity.js
@@ -65,7 +65,7 @@ Identity.prototype.Schema =
"" +
"" +
"" +
- "" +
+ "" +
"" +
"tokens" +
"" +
diff --git a/binaries/data/mods/public/simulation/data/auras/teambonuses/gaul_player_teambonus.json b/binaries/data/mods/public/simulation/data/auras/teambonuses/gaul_player_teambonus.json
index 9096eb5b14..a1478f3095 100644
--- a/binaries/data/mods/public/simulation/data/auras/teambonuses/gaul_player_teambonus.json
+++ b/binaries/data/mods/public/simulation/data/auras/teambonuses/gaul_player_teambonus.json
@@ -1,6 +1,6 @@
{
"type": "global",
- "affects": ["Blacksmith"],
+ "affects": ["Forge"],
"affectedPlayers": ["ExclusiveMutualAlly"],
"modifications": [
{ "value": "ProductionQueue/TechCostMultiplier/food", "multiply": 0.85 },
@@ -10,5 +10,5 @@
{ "value": "ProductionQueue/TechCostMultiplier/time", "multiply": 0.85 }
],
"auraName": "Products from Gaul",
- "auraDescription": "Blacksmiths −15% technology resource costs and research time."
+ "auraDescription": "Forges −15% technology resource costs and research time."
}
diff --git a/binaries/data/mods/public/simulation/data/civs/gaul.json b/binaries/data/mods/public/simulation/data/civs/gaul.json
index ded29257e4..df48a80961 100644
--- a/binaries/data/mods/public/simulation/data/civs/gaul.json
+++ b/binaries/data/mods/public/simulation/data/civs/gaul.json
@@ -88,7 +88,7 @@
{
"Name": "Products from Gaul",
"History": "The Gauls produced and exported swords and scabbards, woolen and leather products, and other arms.",
- "Description": "Blacksmiths −15% technology resource costs and research time."
+ "Description": "Forges −15% technology resource costs and research time."
}
],
"Structures": [],
diff --git a/binaries/data/mods/public/simulation/templates/skirmish/structures/default_blacksmith.xml b/binaries/data/mods/public/simulation/templates/skirmish/structures/default_forge.xml
similarity index 67%
rename from binaries/data/mods/public/simulation/templates/skirmish/structures/default_blacksmith.xml
rename to binaries/data/mods/public/simulation/templates/skirmish/structures/default_forge.xml
index 6ad375dd94..95fce67f2d 100644
--- a/binaries/data/mods/public/simulation/templates/skirmish/structures/default_blacksmith.xml
+++ b/binaries/data/mods/public/simulation/templates/skirmish/structures/default_forge.xml
@@ -1,10 +1,10 @@
-
+
skirm
- structures/{civ}_blacksmith
+ structures/{civ}_forge
structures/hellenes/blacksmith.xml
diff --git a/binaries/data/mods/public/simulation/templates/structures/athen_blacksmith.xml b/binaries/data/mods/public/simulation/templates/structures/athen_forge.xml
similarity index 79%
rename from binaries/data/mods/public/simulation/templates/structures/athen_blacksmith.xml
rename to binaries/data/mods/public/simulation/templates/structures/athen_forge.xml
index 2fbec42049..989373e5f4 100644
--- a/binaries/data/mods/public/simulation/templates/structures/athen_blacksmith.xml
+++ b/binaries/data/mods/public/simulation/templates/structures/athen_forge.xml
@@ -1,5 +1,5 @@
-
+
athen
Chalkeōn
diff --git a/binaries/data/mods/public/simulation/templates/structures/brit_blacksmith.xml b/binaries/data/mods/public/simulation/templates/structures/brit_forge.xml
similarity index 83%
rename from binaries/data/mods/public/simulation/templates/structures/brit_blacksmith.xml
rename to binaries/data/mods/public/simulation/templates/structures/brit_forge.xml
index 68d4487162..c2a774ec79 100644
--- a/binaries/data/mods/public/simulation/templates/structures/brit_blacksmith.xml
+++ b/binaries/data/mods/public/simulation/templates/structures/brit_forge.xml
@@ -1,5 +1,5 @@
-
+
2
diff --git a/binaries/data/mods/public/simulation/templates/structures/cart_blacksmith.xml b/binaries/data/mods/public/simulation/templates/structures/cart_forge.xml
similarity index 76%
rename from binaries/data/mods/public/simulation/templates/structures/cart_blacksmith.xml
rename to binaries/data/mods/public/simulation/templates/structures/cart_forge.xml
index 3cfb6b97ee..5de75bf843 100644
--- a/binaries/data/mods/public/simulation/templates/structures/cart_blacksmith.xml
+++ b/binaries/data/mods/public/simulation/templates/structures/cart_forge.xml
@@ -1,5 +1,5 @@
-
+
cart
diff --git a/binaries/data/mods/public/simulation/templates/structures/gaul_blacksmith.xml b/binaries/data/mods/public/simulation/templates/structures/gaul_forge.xml
similarity index 83%
rename from binaries/data/mods/public/simulation/templates/structures/gaul_blacksmith.xml
rename to binaries/data/mods/public/simulation/templates/structures/gaul_forge.xml
index 599f4212a6..00e6ed2520 100644
--- a/binaries/data/mods/public/simulation/templates/structures/gaul_blacksmith.xml
+++ b/binaries/data/mods/public/simulation/templates/structures/gaul_forge.xml
@@ -1,5 +1,5 @@
-
+
2
diff --git a/binaries/data/mods/public/simulation/templates/structures/iber_blacksmith.xml b/binaries/data/mods/public/simulation/templates/structures/iber_forge.xml
similarity index 85%
rename from binaries/data/mods/public/simulation/templates/structures/iber_blacksmith.xml
rename to binaries/data/mods/public/simulation/templates/structures/iber_forge.xml
index a63c5ecf99..bfeca1c39f 100644
--- a/binaries/data/mods/public/simulation/templates/structures/iber_blacksmith.xml
+++ b/binaries/data/mods/public/simulation/templates/structures/iber_forge.xml
@@ -1,5 +1,5 @@
-
+
iber
Harotz
diff --git a/binaries/data/mods/public/simulation/templates/structures/kush_blacksmith.xml b/binaries/data/mods/public/simulation/templates/structures/kush_forge.xml
similarity index 80%
rename from binaries/data/mods/public/simulation/templates/structures/kush_blacksmith.xml
rename to binaries/data/mods/public/simulation/templates/structures/kush_forge.xml
index f3e956372e..80244ee310 100644
--- a/binaries/data/mods/public/simulation/templates/structures/kush_blacksmith.xml
+++ b/binaries/data/mods/public/simulation/templates/structures/kush_forge.xml
@@ -1,5 +1,5 @@
-
+
kush
hmw hʿy n rȝ-ʿ
diff --git a/binaries/data/mods/public/simulation/templates/structures/mace_blacksmith.xml b/binaries/data/mods/public/simulation/templates/structures/mace_forge.xml
similarity index 79%
rename from binaries/data/mods/public/simulation/templates/structures/mace_blacksmith.xml
rename to binaries/data/mods/public/simulation/templates/structures/mace_forge.xml
index 9ead166a3c..f1414a379b 100644
--- a/binaries/data/mods/public/simulation/templates/structures/mace_blacksmith.xml
+++ b/binaries/data/mods/public/simulation/templates/structures/mace_forge.xml
@@ -1,5 +1,5 @@
-
+
mace
Chalkeōn
diff --git a/binaries/data/mods/public/simulation/templates/structures/maur_blacksmith.xml b/binaries/data/mods/public/simulation/templates/structures/maur_forge.xml
similarity index 85%
rename from binaries/data/mods/public/simulation/templates/structures/maur_blacksmith.xml
rename to binaries/data/mods/public/simulation/templates/structures/maur_forge.xml
index 4c779d3b32..2f6c56be80 100644
--- a/binaries/data/mods/public/simulation/templates/structures/maur_blacksmith.xml
+++ b/binaries/data/mods/public/simulation/templates/structures/maur_forge.xml
@@ -1,5 +1,5 @@
-
+
maur
Lohakāra
diff --git a/binaries/data/mods/public/simulation/templates/structures/pers_blacksmith.xml b/binaries/data/mods/public/simulation/templates/structures/pers_forge.xml
similarity index 79%
rename from binaries/data/mods/public/simulation/templates/structures/pers_blacksmith.xml
rename to binaries/data/mods/public/simulation/templates/structures/pers_forge.xml
index 06c603c3a5..b78c885150 100644
--- a/binaries/data/mods/public/simulation/templates/structures/pers_blacksmith.xml
+++ b/binaries/data/mods/public/simulation/templates/structures/pers_forge.xml
@@ -1,5 +1,5 @@
-
+
pers
Arštišta
diff --git a/binaries/data/mods/public/simulation/templates/structures/ptol_blacksmith.xml b/binaries/data/mods/public/simulation/templates/structures/ptol_forge.xml
similarity index 79%
rename from binaries/data/mods/public/simulation/templates/structures/ptol_blacksmith.xml
rename to binaries/data/mods/public/simulation/templates/structures/ptol_forge.xml
index 477590c8f4..f4135145ba 100644
--- a/binaries/data/mods/public/simulation/templates/structures/ptol_blacksmith.xml
+++ b/binaries/data/mods/public/simulation/templates/structures/ptol_forge.xml
@@ -1,5 +1,5 @@
-
+
ptol
Chalkeōn
diff --git a/binaries/data/mods/public/simulation/templates/structures/rome_blacksmith.xml b/binaries/data/mods/public/simulation/templates/structures/rome_forge.xml
similarity index 80%
rename from binaries/data/mods/public/simulation/templates/structures/rome_blacksmith.xml
rename to binaries/data/mods/public/simulation/templates/structures/rome_forge.xml
index 420ab7fe7d..f214e1a104 100644
--- a/binaries/data/mods/public/simulation/templates/structures/rome_blacksmith.xml
+++ b/binaries/data/mods/public/simulation/templates/structures/rome_forge.xml
@@ -1,5 +1,5 @@
-
+
rome
Armāmentārium
diff --git a/binaries/data/mods/public/simulation/templates/structures/sele_blacksmith.xml b/binaries/data/mods/public/simulation/templates/structures/sele_forge.xml
similarity index 79%
rename from binaries/data/mods/public/simulation/templates/structures/sele_blacksmith.xml
rename to binaries/data/mods/public/simulation/templates/structures/sele_forge.xml
index ef80f42406..434fafe9f2 100644
--- a/binaries/data/mods/public/simulation/templates/structures/sele_blacksmith.xml
+++ b/binaries/data/mods/public/simulation/templates/structures/sele_forge.xml
@@ -1,5 +1,5 @@
-
+
sele
Chalkeōn
diff --git a/binaries/data/mods/public/simulation/templates/structures/spart_blacksmith.xml b/binaries/data/mods/public/simulation/templates/structures/spart_forge.xml
similarity index 79%
rename from binaries/data/mods/public/simulation/templates/structures/spart_blacksmith.xml
rename to binaries/data/mods/public/simulation/templates/structures/spart_forge.xml
index 5563e0bbe6..7a83b12e2f 100644
--- a/binaries/data/mods/public/simulation/templates/structures/spart_blacksmith.xml
+++ b/binaries/data/mods/public/simulation/templates/structures/spart_forge.xml
@@ -1,5 +1,5 @@
-
+
spart
Chalkeōn
diff --git a/binaries/data/mods/public/simulation/templates/template_structure_military_blacksmith.xml b/binaries/data/mods/public/simulation/templates/template_structure_military_forge.xml
similarity index 82%
rename from binaries/data/mods/public/simulation/templates/template_structure_military_blacksmith.xml
rename to binaries/data/mods/public/simulation/templates/template_structure_military_forge.xml
index f506cc1aca..75fe6355eb 100644
--- a/binaries/data/mods/public/simulation/templates/template_structure_military_blacksmith.xml
+++ b/binaries/data/mods/public/simulation/templates/template_structure_military_forge.xml
@@ -19,11 +19,11 @@
decay|rubble/rubble_stone_4x4
- Blacksmith
- template_structure_military_blacksmith
+ Forge
+ template_structure_military_forge
Research attack and armor technologies.
-ConquestCritical
- Town Blacksmith
+ Town Forge
structures/blacksmith.png
phase_town
@@ -52,8 +52,8 @@
-
- interface/complete/building/complete_blacksmith.xml
+
+ interface/complete/building/complete_forge.xml
diff --git a/binaries/data/mods/public/simulation/templates/template_unit_infantry.xml b/binaries/data/mods/public/simulation/templates/template_unit_infantry.xml
index ebe46bc958..c9cae20a8b 100644
--- a/binaries/data/mods/public/simulation/templates/template_unit_infantry.xml
+++ b/binaries/data/mods/public/simulation/templates/template_unit_infantry.xml
@@ -37,7 +37,7 @@
structures/{civ}_sentry_tower
structures/{civ}_dock
structures/{civ}_barracks
- structures/{civ}_blacksmith
+ structures/{civ}_forge
structures/{civ}_temple
structures/{civ}_market
structures/{civ}_defense_tower
diff --git a/binaries/data/mods/public/simulation/templates/template_unit_support_female_citizen.xml b/binaries/data/mods/public/simulation/templates/template_unit_support_female_citizen.xml
index 9b4de8e371..27a1235b07 100644
--- a/binaries/data/mods/public/simulation/templates/template_unit_support_female_citizen.xml
+++ b/binaries/data/mods/public/simulation/templates/template_unit_support_female_citizen.xml
@@ -39,7 +39,7 @@
structures/{civ}_sentry_tower
structures/{civ}_dock
structures/{civ}_barracks
- structures/{civ}_blacksmith
+ structures/{civ}_forge
structures/{civ}_temple
structures/{civ}_market
structures/{civ}_defense_tower
diff --git a/binaries/data/mods/public/simulation/templates/template_unit_support_slave.xml b/binaries/data/mods/public/simulation/templates/template_unit_support_slave.xml
index afbb73ad4a..23b165a725 100644
--- a/binaries/data/mods/public/simulation/templates/template_unit_support_slave.xml
+++ b/binaries/data/mods/public/simulation/templates/template_unit_support_slave.xml
@@ -16,7 +16,7 @@
structures/{civ}_sentry_tower
structures/{civ}_dock
structures/{civ}_barracks
- structures/{civ}_blacksmith
+ structures/{civ}_forge
structures/{civ}_temple
structures/{civ}_market
structures/{civ}_defense_tower
diff --git a/binaries/data/mods/public/simulation/ai/petra/headquarters.js b/binaries/data/mods/public/simulation/ai/petra/headquarters.js
index b4f44c6171..a9c0578bc8 100644
--- a/binaries/data/mods/public/simulation/ai/petra/headquarters.js
+++ b/binaries/data/mods/public/simulation/ai/petra/headquarters.js
@@ -570,10 +570,10 @@ PETRA.HQ.prototype.checkPhaseRequirements = function(gameState, queues)
queue = "economicBuilding";
break;
}
- if (!gameState.getOwnEntitiesByClass("Blacksmith", true).hasEntities() &&
- this.canBuild(gameState, "structures/{civ}_blacksmith"))
+ if (!gameState.getOwnEntitiesByClass("Forge", true).hasEntities() &&
+ this.canBuild(gameState, "structures/{civ}_forge"))
{
- plan = new PETRA.ConstructionPlan(gameState, "structures/{civ}_blacksmith", { "phaseUp": true });
+ plan = new PETRA.ConstructionPlan(gameState, "structures/{civ}_forge", { "phaseUp": true });
queue = "militaryBuilding";
break;
}
@@ -1896,17 +1896,17 @@ PETRA.HQ.prototype.buildDefenses = function(gameState, queues)
}
};
-PETRA.HQ.prototype.buildBlacksmith = function(gameState, queues)
+PETRA.HQ.prototype.buildForge = function(gameState, queues)
{
- if (this.getAccountedPopulation(gameState) < this.Config.Military.popForBlacksmith ||
- queues.militaryBuilding.hasQueuedUnits() || gameState.getOwnEntitiesByClass("Blacksmith", true).length)
+ if (this.getAccountedPopulation(gameState) < this.Config.Military.popForForge ||
+ queues.militaryBuilding.hasQueuedUnits() || gameState.getOwnEntitiesByClass("Forge", true).length)
return;
// Build a market before the blacksmith.
if (!gameState.getOwnEntitiesByClass("Market", true).hasEntities())
return;
- if (this.canBuild(gameState, "structures/{civ}_blacksmith"))
- queues.militaryBuilding.addPlan(new PETRA.ConstructionPlan(gameState, "structures/{civ}_blacksmith"));
+ if (this.canBuild(gameState, "structures/{civ}_forge"))
+ queues.militaryBuilding.addPlan(new PETRA.ConstructionPlan(gameState, "structures/{civ}_forge"));
};
/**
@@ -2734,7 +2734,7 @@ PETRA.HQ.prototype.update = function(gameState, queues, events)
if (!this.saveResources)
{
- this.buildBlacksmith(gameState, queues);
+ this.buildForge(gameState, queues);
this.buildTemple(gameState, queues);
}
@@ -1896,17 +1896,17 @@ PETRA.HQ.prototype.buildDefenses = function(gameState, queues)
return;
- // Build a market before the blacksmith.
+ // Build a Market before the Forge.
if (!gameState.getOwnEntitiesByClass("Market", true).hasEntities())
return;